@@ -1,4 +1,6 @@
-###################
+#!/usr/bin/env python
+
+####################
 ################### Do zrobienia:
 #################    - ukrywanie aplikacji, updateminiatures przy aktywacji okna
 #- poprawa przyblizenia
@@ -10,6 +12,7 @@ from PySide.QtMaemo5 import *
 from PySide.QtGui import QImageReader, QWidget, QGesture, QImage, QMessageBox, QMenu, QDialog, QPushButton, QApplication, QFileDialog, QDesktopWidget, QInputDialog, QSizePolicy, QScrollArea, QIcon, QGridLayout, QAction, QPalette, QToolButton, QMainWindow, QPixmap, QLabel
 import os, glob, md5, math
 import dbus
+import osso
 import dbus.service
 import dbus.mainloop.glib
 
@@ -299,12 +302,13 @@ class Main(QMainWindow): ################## Main Class ##################
   layoutPortrait = QGridLayout
   laySpacing = 10
   size = 6
-  dirPix = "/home/user/MyDocs/Programy_python"
+  dirPix = "/home/user/MyDocs/DCIM"
   adjustedHeight = 0
   
   def __init__(self, size, parent=None):
     super(Main, self).__init__()
  
+    self.osso_c = osso.Context("maepygallery", "0.1.3", False)
     self.reader = QImageReader()
     self.setWindowTitle("MaePyGallery - " + self.dirPix)
     self.showMaximized()
